==> lxqt-session-0.9.0.tar.xz: lxqt-session-0.9.0/lxqt-config-session/translations/lxqt-config-session_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Urejanje</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Ukaz:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Počakaj na sistemsko vrstico</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Izberite program</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="177"/>
        <source>Global Autostart</source>
        <translation>Globalni samodejni zagon</translation>
    </message>
    <message>
        <source>LxQt Autostart</source>
        <translation type="vanished">Samodejni zagon za lxqt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="179"/>
        <source>LXQt Autostart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="197"/>
        <source>Location: %1</source>
        <translation>Lokacija: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="199"/>
        <source>Overrides: %1</source>
        <translation>Povozi: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Urejanje</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Samodejni zagon programa</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="82"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="82"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Datoteka »%1« že obstaja.</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Upravljalnik oken</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask confirmation to leave session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Osnovne nastavitve</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="84"/>
        <source>Select a window manager</source>
        <translation>Izberite upravljalnika oken</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Izberite posnemovalnika terminala</translation>
    </message>
    <message>
        <location filename="../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Izberite spletni brskalnik</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Privzeti programi</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Posnemovalnik termina:</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="52"/>
        <location filename="../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Spletni brskalnik:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="30"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="37"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="63"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Okoljske spremenljivke (napredno)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="74"/>
        <source>Variable Name</source>
        <translation>Ime spremenljivke</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="79"/>
        <source>Value</source>
        <translation>Vrednost</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="85"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <source>LxQt Session Configuration</source>
        <translation type="vanished">Nastavitve seje LxQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="43"/>
        <source>LXQt Session Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="46"/>
        <source>Basic Settings</source>
        <translation>Osnovne nastavitve</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="52"/>
        <source>Default Applications</source>
        <translation>Privzeti programi</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="55"/>
        <source>Autostart</source>
        <translation>Samodejni zagon</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="60"/>
        <source>Environment (Advanced)</source>
        <translation>Okolje (napredno)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="84"/>
        <source>Session Restart Required</source>
        <translation>Potreben je ponoven zagon seje</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="85"/>
        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
        <translation>Za ponovno naložitev nastavitev morate znova zagnati sejo namizja (lxqt-session). Iz glavnega menija izberite Odjavi.</translation>
    </message>
</context>
</TS>

==> lxqt-session-0.10.0.tar.xz: lxqt-session-0.10.0/lxqt-config-session/translations/lxqt-config-session_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Urejanje</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Ime:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Ukaz:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Počakaj na sistemsko vrstico</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>Izberite program</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="192"/>
        <source>Global Autostart</source>
        <translation>Globalni samodejni zagon</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="194"/>
        <source>LXQt Autostart</source>
        <translation>Samodejni zagon za lxqt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="212"/>
        <source>Location: %1</source>
        <translation>Lokacija: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="214"/>
        <source>Overrides: %1</source>
        <translation>Povozi: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Urejanje</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Samodejni zagon programa</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Datoteka »%1« že obstaja.</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Upravljalnik oken</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Osnovne nastavitve</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="137"/>
        <source>Select a window manager</source>
        <translation>Izberite upravljalnika oken</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>Izberite posnemovalnika terminala</translation>
    </message>
    <message>
        <location filename="../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>Izberite spletni brskalnik</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>Privzeti programi</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>Posnemovalnik termina:</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="52"/>
        <location filename="../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>Iskanje ...</translation>
    </message>
    <message>
        <location filename="../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>Spletni brskalnik:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Izbriši</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Okoljske spremenljivke (napredno)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Ime spremenljivke</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Vrednost</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <source>LXQt Session Configuration</source>
        <translation type="vanished">Nastavitve seje LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Osnovne nastavitve</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>Privzeti programi</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="56"/>
        <source>Locations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>Samodejni zagon</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>Okolje (napredno)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Session Restart Required</source>
        <translation>Potreben je ponoven zagon seje</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="93"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You need to restart desktop session (lxqt-session) to reload settings. Use logout from the main menu.</source>
        <translation type="vanished">Za ponovno naložitev nastavitev morate znova zagnati sejo namizja (lxqt-session). Iz glavnega menija izberite Odjavi.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="99"/>
        <source>Locations for Personal Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="160"/>
        <source>LXQt Session Settings - Locations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="161"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="177"/>
        <source>Choose Location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="59"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="60"/>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="61"/>
        <source>Templates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="62"/>
        <source>Public Share</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
